@@ -324,20 +324,20 @@ if ( !function_exists("quoted_printable_encode") ) {
 }
 
 
-if ( !function_exists("clean_by_regex") ) {
+if ( !function_exists("check_by_regex") ) {
   /**
-  * Clean a value by applying a regex to it.  If it is an array apply it to
+  * Verify a value is OK by testing a regex against it.  If it is an array apply it to
   * each element in the array recursively.  If it is an object we don't mess
   * with it.
   */
-  function clean_by_regex( $val, $regex ) {
+  function check_by_regex( $val, $regex ) {
     if ( is_null($val) ) return null;
     switch( $regex ) {
       case 'int':     $regex = '#^\d+$#';     break;
     }
     if ( is_array($val) ) {
       foreach( $val AS $k => $v ) {
-        $val[$k] = clean_by_regex($v,$regex);
+        $val[$k] = check_by_regex($v,$regex);
       }
     }
     else if ( ! is_object($val) ) {
@@ -390,7 +390,7 @@ if ( !function_exists("param_to_global") ) {
     if ( !isset($result) ) return null;
 
     if ( isset($match_regex) ) {
-      $result = clean_by_regex( $result, $match_regex );
+      $result = check_by_regex( $result, $match_regex );
     }
 
     $GLOBALS[$varname] = $result;
@@ -404,8 +404,7 @@ if ( !function_exists("get_fields") ) {
   * @var array $_AWL_field_cache is a cache of the field names for a table
   */
   $_AWL_field_cache = array();
-
-
+  
   /**
   * Get the names of the fields for a particular table
   * @param string $tablename The name of the table.
@@ -415,16 +414,14 @@ if ( !function_exists("get_fields") ) {
     global $_AWL_field_cache;
 
     if ( !isset($_AWL_field_cache[$tablename]) ) {
-      dbg_error_log( "DataUpdate", ":get_fields: Loaded fields for table '$tablename'" );
-      $sql = "SELECT f.attname, t.typname, f.atttypmod FROM pg_attribute f ";
-      $sql .= "JOIN pg_class c ON ( f.attrelid = c.oid ) ";
-      $sql .= "JOIN pg_type t ON ( f.atttypid = t.oid ) ";
-      $sql .= "WHERE relname = ? AND attnum >= 0 order by f.attnum;";
-      $qry = new PgQuery( $sql, $tablename );
-      $qry->Exec("DataUpdate");
+      dbg_error_log( "core", ":get_fields: Loading fields for table '$tablename'" );
+      $qry = new AwlQuery();
+      $db = $qry->GetConnection();
+      $qry->SetSQL($db->GetFields($tablename));
+      $qry->Exec("core");
       $fields = array();
       while( $row = $qry->Fetch() ) {
-        $fields["$row->attname"] = $row->typname . ($row->atttypmod != -1 ? sprintf('(%d)',$row->atttypmod) : '');
+        $fields[$row->fieldname] = $row->typename . ($row->precision >= 0 ? sprintf('(%d)',$row->precision) : '');
       }
       $_AWL_field_cache[$tablename] = $fields;
     }
@@ -527,7 +524,20 @@ function olson_from_tzstring( $tzstring ) {
     return $matches[1];
   }
   switch( $tzstring ) {
-    case 'New Zealand Standard Time': return 'Pacific/Auckland'; break;
+    case 'New Zealand Standard Time': case 'New Zealand Daylight Time': return 'Pacific/Auckland'; break;
+    case 'Central Standard Time':     case 'Central Daylight Time':     return 'America/Chicago';  break;
+    case 'Eastern Standard Time':     case 'Eastern Daylight Time':     return 'America/New_York'; break;
+    case 'Pacific Standard Time':     case 'Pacific Daylight Time':     return 'America/Los_Angeles'; break;
   }
   return null;
 }
+
+
+/**
+ * Return the AWL version
+ */
+function awl_version() {
+  global $c;
+$c->awl_library_version = 0.46;
+  return $c->awl_library_version;
+}
\ No newline at end of file
