@@ -266,7 +266,14 @@ class AwlQuery
 
 
 
+ /**
+  * Get the current database connection for this query
+  */
+  function GetConnection() {
+    return $this->connection;
+  }
 
+  
   /**
   * Log query, optionally with file and line location of the caller.
   *
@@ -301,12 +308,12 @@ class AwlQuery
   * @param mixed $str Data to be converted to a string suitable for including as a value in SQL.
   * @return string NULL, TRUE, FALSE, a plain number, or the original string quoted and with ' and \ characters escaped
   */
-  function quote($str = null) {
-    if ( !isset($this->connection) ) {
+  public static function quote($str = null) {
+    global $_awl_dbconn;
+    if ( !isset($_awl_dbconn) ) {
       _awl_connect_configured_database();
-      $this->connection = $GLOBALS['_awl_dbconn'];
     }
-    return $this->connection->Quote($str);
+    return $_awl_dbconn->Quote($str);
   }
 
 
@@ -431,6 +438,14 @@ class AwlQuery
   }
 
 
+  /**
+  * Return the current rownum in the retrieved set
+  */
+  function rownum() {
+    return $this->rownum;
+  }
+
+
   /**
   * Returns the current state of a transaction, indicating if we have begun a transaction, whether the transaction
   * has failed, or if we are not in a transaction.
@@ -570,8 +585,10 @@ class AwlQuery
         printf( "\n=====================\n" );
         printf( "%s[%d] QF: %s\n", $file, $line, $this->errorstring);
         printf( "%s\n", $this->querystring );
-        foreach( $this->bound_parameters AS $k => $v ) {
-          printf( "    %-18s \t=> '%s'\n", "'$k'", $v );
+        if ( isset($this->bound_parameters) ) {
+          foreach( $this->bound_parameters AS $k => $v ) {
+            printf( "    %-18s \t=> '%s'\n", "'$k'", $v );
+          }          
         }
         printf( ".....................\n" );
       }
