@@ -84,14 +84,16 @@ class vProperty {
    */
   function ParseFrom( $propstring ) {
     $this->rendered = (strlen($propstring) < 73 ? $propstring : null);  // Only pre-rendered if we didn't unescape it
-    $pos = strpos( $propstring, ':');
-    $start = substr( $propstring, 0, $pos);
 
-    $unescaped = str_replace( '\\n', "\n", substr( $propstring, $pos + 1));
-    $unescaped = str_replace( '\\N', "\n", $unescaped);
-    $this->content = preg_replace( "/\\\\([,;:\"\\\\])/", '$1', $unescaped);
+    $unescaped = preg_replace( '{\\\\[nN]}', "\n", $propstring);
+
+    // Split into two parts on : which is not preceded by a \
+    list( $start, $values) = preg_split( '{(?<!\\\\):}', $unescaped, 2);
+    $this->content = preg_replace( "/\\\\([,;:\"\\\\])/", '$1', $values);
+
+    // Split on ; which is not preceded by a \
+    $parameters = preg_split( '{(?<!\\\\);}', $start);
 
-    $parameters = explode(';',$start);
     $this->name = strtoupper(array_shift( $parameters ));
     $this->parameters = array();
     foreach( $parameters AS $k => $v ) {
@@ -249,7 +251,12 @@ class vProperty {
     return $this->rendered;
   }
 
+  
+  public function __toString() {
+    return $this->Render();
+  }
 
+  
   /**
    * Test a PROP-FILTER or PARAM-FILTER and return a true/false
    * PROP-FILTER (is-defined | is-not-defined | ((time-range | text-match)?, param-filter*))
@@ -395,7 +402,7 @@ class vComponent {
     }
   }
 
-
+  
   /**
   * Collect an array of all parameters of our properties which are the specified type
   * Mainly used for collecting the full variety of references TZIDs
@@ -550,9 +557,12 @@ class vComponent {
   */
   function GetProperty( $type ) {
     foreach( $this->properties AS $k => $v ) {
-      if ( $v->Name() == $type ) {
+      if ( is_object($v) && $v->Name() == $type ) {
         return $v;
       }
+      else if ( !is_object($v) ) {
+        debug_error_log("ERROR", 'vComponent::GetProperty(): Trying to get %s on %s which is not an object!', $type, $v );
+      }
     }
     /** So we can call methods on the result of this, make sure we always return a vProperty of some kind */
     return null;
@@ -634,6 +644,14 @@ class vComponent {
   }
 
 
+  /**
+   * Return number of components
+   */
+  function ComponentCount() {
+    return count($this->components);
+  }
+
+
   /**
   * Get all sub-components, or at least get those matching a type, or failling to match,
   * should the second parameter be set to false. Component types may be a string or an array
@@ -700,7 +718,7 @@ class vComponent {
   */
   function SetComponents( $new_component, $type = null ) {
     if ( isset($this->rendered) ) unset($this->rendered);
-    if ( count($new_component) > 0 ) $this->ClearComponents($type);
+    $this->ClearComponents($type);
     foreach( $new_component AS $k => $v ) {
       $this->components[] = $v;
     }
@@ -788,6 +806,12 @@ class vComponent {
   }
 
 
+    
+  public function __toString() {
+    return $this->Render();
+  }
+
+  
   /**
   * Return an array of properties matching the specified path
   *
